Selector

Enum Selector 

pub enum Selector {
    Type(String),
    Class(String),
    Id(String),
    Universal,
    PseudoClass(PseudoClass),
    Descendant(Box<Selector>, Box<Selector>),
    Child(Box<Selector>, Box<Selector>),
    Compound(Vec<Selector>),
}
TCSS selector — a single selector or combinator expression.

Variants



Type(String)

Matches widgets by type name, e.g. Button



Class(String)

Matches widgets with a CSS class, e.g. .active



Id(String)

Matches widgets with a specific ID, e.g. #sidebar



Universal

Matches any widget (*)



PseudoClass(PseudoClass)

Matches widgets with a given pseudo-class, e.g. :focus



Descendant(Box<Selector>, Box<Selector>)

Matches a widget that is any descendant of the left selector, e.g. Screen Button



Child(Box<Selector>, Box<Selector>)

Matches a widget that is a direct child of the left selector, e.g. Container > Button



Compound(Vec<Selector>)

Multiple simple selectors that all apply to the same element, e.g. Button.active:focus

Implementations

Source

impl Selector

pub fn specificity(&self) -> Specificity

Calculate specificity for this selector.