pub enum DockEdge {
Top,
Bottom,
Left,
Right,
}Expand description
An edge of the screen where a docked widget is anchored.
Variants
Top
Widget is docked to the top of its container.
Bottom
Widget is docked to the bottom of its container.
Left
Widget is docked to the left of its container.
Right
Widget is docked to the right of its container.