pub struct WidgetId(/* private fields */);Trait Implementations
Sourceimpl Key for WidgetId
impl Key for WidgetId
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for WidgetId
impl Ord for WidgetId
Sourceimpl PartialOrd for WidgetId
impl PartialOrd for WidgetId
impl Copy for WidgetId
impl Eq for WidgetId
impl StructuralPartialEq for WidgetId